/*
<DEPENDENCIES>
    <DEPENDS>Logger</DEPENDS>
    <DEPENDS>Browser</DEPENDS>
    <DEPENDS>Actions</DEPENDS>
</DEPENDENCIES>
*/
function DialogStoryRowSystem(sId, oStoryElementSystem, oView)
{
   this.init(sId, oStoryElementSystem, oView);
}
DialogStoryRowSystem.prototype.init = function(sId, oStoryElementSystem, oView)
{
  this.sId = sId;
  this.oStoryElement = oStoryElementSystem;
  this.view = oView;
  this.soundBroker = null;
  this.element = null;
  this.textElement = null;
  this.bTextHighlighted = false;
}
DialogStoryRowSystem.prototype.setSoundBroker = function(soundBroker)
{
  this.soundBroker = soundBroker;
}
DialogStoryRowSystem.prototype.show = function()
{
  this.appendToDisplay(this.view.displayElement);
}
DialogStoryRowSystem.prototype.hide = function()
{
  this.removeFromDisplay(this.view.displayElement);
}
DialogStoryRowSystem.prototype.appendToDisplay = function(parentNode)
{
  if(!this.element)
  {
    this.buildHTMLRepresentation();
  }
  parentNode.appendChild(this.element);
}
DialogStoryRowSystem.prototype.removeFromDisplay = function(parentNode)
{
  if(this.element)
  {
    Browser.removeNodeFromParent(this.element);
  }
}
DialogStoryRowSystem.prototype.buildHTMLRepresentation = function()
{
  var textString = null;
  if(this.view.sTextStyleClass)
  {
    textString = '<span id="' + this.sId + '_text" class="' + this.view.sTextStyleClass + '">' + this.oStoryElement.getText() + "</span>";
  }
  else
  {
    textString = '<span id="' + this.sId + '_text">' + this.oStoryElement.getText() + "</span>";
  }
  var rowDivString;
  if(this.view.sSystemRowStyleClass)
  {
    rowDivString = '<div id="' + this.sId + '_rowdiv" class="' + this.view.sSystemRowStyleClass + '"></div>';
  }
  else
  {
    rowDivString = '<div id="' + this.sId + '_rowdiv"></div>';
  }
  var divElement = document.createElement('div');
  divElement.style.position = 'relative';
  divElement.innerHTML = rowDivString;
  var rowDivElement = divElement.firstChild;
  rowDivElement.innerHTML = textString;
  this.textElement = rowDivElement.firstChild;
  if(this.soundBroker)
  {
    this.soundBroker.addSoundStartedHandle(this.getHighlightTextAction());
    this.soundBroker.addSoundStoppedHandle(this.getNormalTextAction());
  }
  this.element = divElement;
}
DialogStoryRowSystem.prototype.highlightText = function()
{
  if(!this.bTextHighlighted)
  {
    if(this.view.sFgColorHighlight)
    {
      this.textElement.style.color = this.view.sFgColorHighlight;
    }
    if(this.view.sBgColorHighlight)
    {
      this.textElement.style.backgroundColor = this.view.sBgColorHighlight;
    }
    this.bTextHighlighted = true;
  }
}
DialogStoryRowSystem.prototype.normalText = function()
{
  if(this.bTextHighlighted)
  {
    this.textElement.style.color = '';
    this.textElement.style.backgroundColor = '';
    this.bTextHighlighted = false;
  }
}
DialogStoryRowSystem.prototype.getHighlightTextAction = function()
{
  return new ObjectMethodAction(this, "highlightText");
}
DialogStoryRowSystem.prototype.getNormalTextAction = function()
{
  return new ObjectMethodAction(this, "normalText");
}
